summaryrefslogtreecommitdiffstats
path: root/kbfxlib/common/kbfxkiodownload.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbfxlib/common/kbfxkiodownload.h')
-rw-r--r--kbfxlib/common/kbfxkiodownload.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/kbfxlib/common/kbfxkiodownload.h b/kbfxlib/common/kbfxkiodownload.h
index 61efb91..7765076 100644
--- a/kbfxlib/common/kbfxkiodownload.h
+++ b/kbfxlib/common/kbfxkiodownload.h
@@ -29,19 +29,20 @@
/**
* @author PhobosK <[email protected]>
*/
-class KbfxKioDownload : public QObject
+class KbfxKioDownload : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- KbfxKioDownload ( QObject * parent = 0, const char * name = 0 );
+ KbfxKioDownload ( TQObject * tqparent = 0, const char * name = 0 );
~KbfxKioDownload();
- /* KbfxKioDownload invocation - pass an url as QString */
- void KbfxKioDownloadStart ( QString &url );
+ /* KbfxKioDownload invocation - pass an url as TQString */
+ void KbfxKioDownloadStart ( TQString &url );
/* return temp file name for the download */
- QString KbfxBrowserTmpFile() {return m_KbfxBrowserTmpFile;}
+ TQString KbfxBrowserTmpFile() {return m_KbfxBrowserTmpFile;}
/* return error number occured during download
* see definition in global.h
@@ -49,12 +50,12 @@ class KbfxKioDownload : public QObject
int KbfxBrowserError() {return m_KbfxBrowserError;}
/* return error text occured during download */
- QString KbfxBrowserErrorText() {return m_KbfxBrowserErrorText;}
+ TQString KbfxBrowserErrorText() {return m_KbfxBrowserErrorText;}
protected:
- QString m_KbfxBrowserTmpFile;
+ TQString m_KbfxBrowserTmpFile;
int m_KbfxBrowserError;
- QString m_KbfxBrowserErrorText;
+ TQString m_KbfxBrowserErrorText;
private:
KTempFile tmpF;